@@ -24,8 +24,7 @@
 #include <glib/gi18n-lib.h>
 
 #include <webkit/webkit.h>
-#include <telepathy-glib/dbus.h>
-#include <telepathy-glib/util.h>
+#include <telepathy-glib/telepathy-glib.h>
 
 #include <pango/pango.h>
 #include <gdk/gdk.h>
@@ -1439,6 +1438,8 @@ theme_adium_finalize (GObject *object)
   g_object_unref (self->priv->gsettings_chat);
   g_object_unref (self->priv->gsettings_desktop);
 
+  g_free (self->priv->variant);
+
   G_OBJECT_CLASS (empathy_theme_adium_parent_class)->finalize (object);
 }
 
@@ -1761,20 +1762,17 @@ empathy_adium_path_is_valid (const gchar *path)
   /* The directory has to be *.AdiumMessageStyle per the Adium spec */
   tmp = g_strsplit (path, "/", 0);
   if (tmp == NULL)
-    {
-      g_free (tmp);
-      return FALSE;
-    }
+    return FALSE;
 
   dir = tmp[g_strv_length (tmp) - 1];
 
   if (!g_str_has_suffix (dir, ".AdiumMessageStyle"))
     {
-      g_free (tmp);
+      g_strfreev (tmp);
       return FALSE;
     }
 
-  g_free (tmp);
+  g_strfreev (tmp);
 
   /* The theme is not valid if there is no Info.plist */
   file = g_build_filename (path, "Contents", "Info.plist",
